import NDK, { NDKEvent, type NDKEventId } from '@nostr-dev-kit/ndk';
import { EVENT_KIND_FOLDERS_LIST } from '$lib/customEventKinds';

export class FolderLabel {
	id: NDKEventId;
	name: string;
	icon: string;
	letters: NDKEventId[];

	constructor() {
		this.id = '';
		this.name = '';
		this.icon = '';
		this.letters = [];
	}

	static fromJSON(json: {
		id: NDKEventId;
		name: string;
		icon: string;
		letters?: NDKEventId[];
	}): FolderLabel {
		let folder = new FolderLabel();
		folder.id = json.id;
		folder.name = json.name;
		folder.icon = json.icon;
		if (json.letters) folder.letters = json.letters;
		else folder.letters = [];
		return folder;
	}

	static async getAll(ndk: NDK): Promise<FolderLabel[]> {
		let newFolders = await ndk.fetchEvent({
			kinds: [EVENT_KIND_FOLDERS_LIST],
			'#p': [ndk.activeUser!.pubkey],
			'#d': ['letter-folders']
		});

		if (!newFolders) {
			await FolderLabel.save(ndk, []);
			return [];
		}

		let decrypted = await ndk.signer!.nip44Decrypt(ndk.activeUser!, newFolders.content);
		return JSON.parse(decrypted).map((x) => FolderLabel.fromJSON(x));
	}

	static async save(ndk: NDK, folders: FolderLabel[]) {
		let newFolders = JSON.stringify(folders.map((x) => x.toJson()));
		let newFoldersEncrypted = await ndk.signer!.nip44Encrypt(ndk.activeUser!, newFolders);
		let event = new NDKEvent(ndk);
		event.kind = EVENT_KIND_FOLDERS_LIST;
		event.content = newFoldersEncrypted;
		event.created_at = Math.floor(Date.now() / 1000);
		event.tags = [['d', 'letter-folders'], ['p', ndk.activeUser!.pubkey], ['encrypted']];
		await event.sign(ndk.signer!);
		await event.publish();
	}

	toJson() {
		return {
			id: this.id,
			name: this.name,
			icon: this.icon,
			letters: this.letters
		};
	}
}
