import { error, json } from '@sveltejs/kit';
import { PUBLIC_API_BASE_URL } from '$env/static/public';
import { npubToPubKeyString } from '@arx/utils/nostr.ts';

export async function GET({ url }: { url: URL }) {
	const name = url.searchParams.get('name');
	if (!name) throw error(400, 'Name parameter is required');

	const aliasGetURL = `${PUBLIC_API_BASE_URL}/alias/${name}`;
	const aliasResponse = await fetch(aliasGetURL);
	if (aliasResponse.ok) {
		const npub = await aliasResponse.text();
		const hex = npubToPubKeyString(npub);
		return json({
			names: {
				[name]: hex
			}
		});
	}
	const errorText = await aliasResponse.text();
	if (errorText === '') throw error(404, 'Alias not found');

	throw error(500, errorText);
}
